#ifndef NT2_INCLUDE_FUNCTIONS_MUL_MINUS_I_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MUL_MINUS_I_HPP_INCLUDED

#include <nt2/complex/include/functions/mul_minus_i.hpp>

#endif
